@@ -56,17 +56,15 @@ hyper_tibble.tidync<- function(x, ..., na.rm = TRUE, force = FALSE) {
   if (na.rm) all_na <- Reduce(`&`, lapply(slabs, 
                                           function(a) is.na(as.vector(a))))
   total_prod <- prod(dim(slabs[[1]]))
-out <- tibble::as_tibble(lapply(slabs, as.vector))
+  out <- tibble::as_tibble(lapply(slabs, as.vector))
   
   prod_dims <- 1
-  trans <- attr(slabs, "transforms")
+  dn <- dimnames(slabs[[1]])
+  nm <- names(dn)
 
-  for (i in seq_along(trans)) {
-    nm <- names(trans)[i]
-    nr <- sum(trans[[i]]$selected)
-    out[[nm]] <- rep(dplyr::filter(trans[[nm]], .data$selected)[[nm]], 
-                     each = prod_dims, length.out = total_prod)
-    prod_dims <- prod_dims * nr
+  for (i in seq_along(nm)) {
+    out[[nm[i]]] <- rep(dn[[i]], each = prod_dims, length.out = total_prod)
+    prod_dims <- prod_dims * length(dn[[i]]) 
   }
   if (na.rm) out <- dplyr::filter(out, !all_na)
  out
