@@ -68,16 +68,36 @@ hyper_transforms.default <- function(x, all = FALSE, ...) {
   transforms <- vector("list", nrow(dims))
   names(transforms) <- dims$name
   
+  all_atts <- mutate(x$attribute, low_name = tolower(.data$name))
+  
   for (i in seq_along(transforms)) {
     ll <- list(value = ifelse(rep(dims$coord_dim[i], dims$length[i]), 
                 nc_get(source$source, dims$name[i]), seq_len(dims$length[i])))
     axis <- tibble::as_tibble(ll)
     names(axis)  <- dims$name[i]
+    
     ## axis might have a column called "i"  
     ## tidync/issues/74
     id_value <- dims$dimension[i]
     dim_name <- dims$name[i]
     dim_coord <- dims$coord_dim[i]
+
+    ## Add timestamp for any "time" dimension. Since not all files have a 
+    ## "calendar" attribute or "axis == "T"", just try to create a CFtime
+    ## instance from the "units" attribute and a "calendar" if present
+    ## tidync/issues/54
+    dim_atts <- all_atts %>% dplyr::filter(.data$variable == dim_name)
+    units <- unlist(dim_atts$value[which(dim_atts$low_name == "units")])
+    if (!(is.null(units))) {
+      cal_idx <- which(dim_atts$low_name == "calendar")
+      if (length(cal_idx) == 0) calendar <- "standard"
+      else calendar <- unlist(dim_atts$value[cal_idx])
+      try({
+        cft <- CFtime::CFtime(units, calendar, axis[[1]])
+        axis$timestamp = CFtime::as_timestamp(cft)
+      }, silent = TRUE)
+    }
+    
     axis <- mutate(axis, 
                    index = row_number(), 
                    id = id_value, 
